# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seqq.models.seqq_service_batch_start_searches_request import SeqqServiceBatchStartSearchesRequest

class TestSeqqServiceBatchStartSearchesRequest(unittest.TestCase):
    """SeqqServiceBatchStartSearchesRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SeqqServiceBatchStartSearchesRequest:
        """Test SeqqServiceBatchStartSearchesRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SeqqServiceBatchStartSearchesRequest`
        """
        model = SeqqServiceBatchStartSearchesRequest()
        if include_optional:
            return SeqqServiceBatchStartSearchesRequest(
                requests = [
                    seqq.models.v1alpha_start_search_request.v1alphaStartSearchRequest(
                        collection = '', 
                        search = seqq.models.apiv1alpha_search.apiv1alphaSearch(
                            name = '', 
                            query = '', 
                            code = 'CODE_UNSPECIFIED', 
                            prefix = '', 
                            query_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            query_duration = '', 
                            hits = [
                                seqq.models.v1alpha_hit.v1alphaHit(
                                    saccver = '', 
                                    pident = 1.337, 
                                    length = '', 
                                    mismatch = '', 
                                    gapopen = '', 
                                    qstart = '', 
                                    qend = '', 
                                    sstart = '', 
                                    send = '', 
                                    evalue = 1.337, 
                                    bitscore = 1.337, )
                                ], 
                            state = 'STATE_UNSPECIFIED', 
                            error = seqq.models.rpc_status.rpcStatus(
                                message = '', 
                                details = [
                                    {
                                        'key' : None
                                        }
                                    ], ), 
                            strategy = seqq.models.v1alpha_strategy.v1alphaStrategy(
                                blastn = seqq.models.v1alpha_blastn.v1alphaBlastn(
                                    task = 'TASK_UNSPECIFIED', ), 
                                blastp = seqq.models.v1alpha_blastp.v1alphaBlastp(), 
                                blastx = seqq.models.v1alpha_blastp.v1alphaBlastp(), 
                                tblastn = seqq.models.v1alpha_tblastn.v1alphaTblastn(), 
                                tblastx = seqq.models.v1alpha_tblastx.v1alphaTblastx(), ), ), )
                    ]
            )
        else:
            return SeqqServiceBatchStartSearchesRequest(
                requests = [
                    seqq.models.v1alpha_start_search_request.v1alphaStartSearchRequest(
                        collection = '', 
                        search = seqq.models.apiv1alpha_search.apiv1alphaSearch(
                            name = '', 
                            query = '', 
                            code = 'CODE_UNSPECIFIED', 
                            prefix = '', 
                            query_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            query_duration = '', 
                            hits = [
                                seqq.models.v1alpha_hit.v1alphaHit(
                                    saccver = '', 
                                    pident = 1.337, 
                                    length = '', 
                                    mismatch = '', 
                                    gapopen = '', 
                                    qstart = '', 
                                    qend = '', 
                                    sstart = '', 
                                    send = '', 
                                    evalue = 1.337, 
                                    bitscore = 1.337, )
                                ], 
                            state = 'STATE_UNSPECIFIED', 
                            error = seqq.models.rpc_status.rpcStatus(
                                message = '', 
                                details = [
                                    {
                                        'key' : None
                                        }
                                    ], ), 
                            strategy = seqq.models.v1alpha_strategy.v1alphaStrategy(
                                blastn = seqq.models.v1alpha_blastn.v1alphaBlastn(
                                    task = 'TASK_UNSPECIFIED', ), 
                                blastp = seqq.models.v1alpha_blastp.v1alphaBlastp(), 
                                blastx = seqq.models.v1alpha_blastp.v1alphaBlastp(), 
                                tblastn = seqq.models.v1alpha_tblastn.v1alphaTblastn(), 
                                tblastx = seqq.models.v1alpha_tblastx.v1alphaTblastx(), ), ), )
                    ],
        )
        """

    def testSeqqServiceBatchStartSearchesRequest(self):
        """Test SeqqServiceBatchStartSearchesRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class BlastnTask(str, Enum):
    """
     - TASK_UNSPECIFIED: TASK_UNSPECIFIED is the default value.  - MEGABLAST: MEGABLAST is a search optimized for highly similar sequences.  - DC_MEGABLAST: DC_MEGABLAST is typically used for inter-species comparisons.  - BLASTN: BLASTN is a standard search.  - BLASTN_SHORT: BLASTN_SHORT is a search optimized for short queries.
    """

    """
    allowed enum values
    """
    TASK_UNSPECIFIED = 'TASK_UNSPECIFIED'
    MEGABLAST = 'MEGABLAST'
    DC_MEGABLAST = 'DC_MEGABLAST'
    BLASTN = 'BLASTN'
    BLASTN_SHORT = 'BLASTN_SHORT'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BlastnTask from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seqq.models.v1alpha_start_search_request import V1alphaStartSearchRequest

class TestV1alphaStartSearchRequest(unittest.TestCase):
    """V1alphaStartSearchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1alphaStartSearchRequest:
        """Test V1alphaStartSearchRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1alphaStartSearchRequest`
        """
        model = V1alphaStartSearchRequest()
        if include_optional:
            return V1alphaStartSearchRequest(
                collection = '',
                search = seqq.models.apiv1alpha_search.apiv1alphaSearch(
                    name = '', 
                    query = '', 
                    code = 'CODE_UNSPECIFIED', 
                    prefix = '', 
                    query_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    query_duration = '', 
                    hits = [
                        seqq.models.v1alpha_hit.v1alphaHit(
                            saccver = '', 
                            pident = 1.337, 
                            length = '', 
                            mismatch = '', 
                            gapopen = '', 
                            qstart = '', 
                            qend = '', 
                            sstart = '', 
                            send = '', 
                            evalue = 1.337, 
                            bitscore = 1.337, )
                        ], 
                    state = 'STATE_UNSPECIFIED', 
                    error = seqq.models.rpc_status.rpcStatus(
                        message = '', 
                        details = [
                            {
                                'key' : None
                                }
                            ], ), 
                    strategy = seqq.models.v1alpha_strategy.v1alphaStrategy(
                        blastn = seqq.models.v1alpha_blastn.v1alphaBlastn(
                            task = 'TASK_UNSPECIFIED', ), 
                        blastp = seqq.models.v1alpha_blastp.v1alphaBlastp(), 
                        blastx = seqq.models.v1alpha_blastp.v1alphaBlastp(), 
                        tblastn = seqq.models.v1alpha_tblastn.v1alphaTblastn(), 
                        tblastx = seqq.models.v1alpha_tblastx.v1alphaTblastx(), ), )
            )
        else:
            return V1alphaStartSearchRequest(
                collection = '',
                search = seqq.models.apiv1alpha_search.apiv1alphaSearch(
                    name = '', 
                    query = '', 
                    code = 'CODE_UNSPECIFIED', 
                    prefix = '', 
                    query_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    query_duration = '', 
                    hits = [
                        seqq.models.v1alpha_hit.v1alphaHit(
                            saccver = '', 
                            pident = 1.337, 
                            length = '', 
                            mismatch = '', 
                            gapopen = '', 
                            qstart = '', 
                            qend = '', 
                            sstart = '', 
                            send = '', 
                            evalue = 1.337, 
                            bitscore = 1.337, )
                        ], 
                    state = 'STATE_UNSPECIFIED', 
                    error = seqq.models.rpc_status.rpcStatus(
                        message = '', 
                        details = [
                            {
                                'key' : None
                                }
                            ], ), 
                    strategy = seqq.models.v1alpha_strategy.v1alphaStrategy(
                        blastn = seqq.models.v1alpha_blastn.v1alphaBlastn(
                            task = 'TASK_UNSPECIFIED', ), 
                        blastp = seqq.models.v1alpha_blastp.v1alphaBlastp(), 
                        blastx = seqq.models.v1alpha_blastp.v1alphaBlastp(), 
                        tblastn = seqq.models.v1alpha_tblastn.v1alphaTblastn(), 
                        tblastx = seqq.models.v1alpha_tblastx.v1alphaTblastx(), ), ),
        )
        """

    def testV1alphaStartSearchRequest(self):
        """Test V1alphaStartSearchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seqq.models.v1alpha_strategy import V1alphaStrategy

class TestV1alphaStrategy(unittest.TestCase):
    """V1alphaStrategy unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1alphaStrategy:
        """Test V1alphaStrategy
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1alphaStrategy`
        """
        model = V1alphaStrategy()
        if include_optional:
            return V1alphaStrategy(
                blastn = seqq.models.v1alpha_blastn.v1alphaBlastn(
                    task = 'TASK_UNSPECIFIED', ),
                blastp = seqq.models.v1alpha_blastp.v1alphaBlastp(),
                blastx = seqq.models.v1alpha_blastp.v1alphaBlastp(),
                tblastn = seqq.models.v1alpha_tblastn.v1alphaTblastn(),
                tblastx = seqq.models.v1alpha_tblastx.v1alphaTblastx()
            )
        else:
            return V1alphaStrategy(
        )
        """

    def testV1alphaStrategy(self):
        """Test V1alphaStrategy"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
